@@ -14,7 +14,7 @@ use with Tk
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ use JSON;
 use Try::Tiny;
 
 ## Version string
-our $VERSION = qq{1.03};
+our $VERSION = qq{1.04};
 
 Readonly::Scalar our $READONLY    => 1;
 
@@ -938,7 +938,7 @@ sub _set_key_bindings
   my $underline   = index($button_text, qq{&});
   if ($underline >= 0)
   {
-    my $keycap = lc(substr($button_text, $underline, 1));
+    my $keycap = lc(substr($button_text, $underline + 1, 1));
     
     $win->bind(qq{<Alt-Key-$keycap>} => sub {${$self->_watch_variable} = 1;});
   }
